@@ -10,7 +10,6 @@ from PySide2.QtGui import Qt
 from PySide2.QtCore import QObject, QEvent
 
 import timecode
-import PIL.Image, PIL.ImageTk
 import os
 
 from peyecoder.video_reader import BufferedVideoReader
@@ -562,9 +561,8 @@ class MainWindow(QtWidgets.QMainWindow):
             return
 
         frame = self.vid.frame
-        image = PIL.Image.fromarray(frame)
-
-        image = QtGui.QImage(image.tobytes(), image.width, image.height, QtGui.QImage.Format_RGB888)
+        h, w, d = frame.shape
+        image = QtGui.QImage(frame.data, w, h, QtGui.QImage.Format_RGB888)
 
         # Draw occluders in image
         painter = QtGui.QPainter(image)
@@ -758,11 +756,11 @@ class MainWindow(QtWidgets.QMainWindow):
         self.show_frame()  # update (and resize) the display of the current frame
 
 
-if __name__ == "__main__":
-
+def run():
+    """Run peyecoder application"""
     app = QtWidgets.QApplication([])
     widget = MainWindow()
     widget.resize(800, 600)
     widget.show()
+    return app.exec_()
 
-    sys.exit(app.exec_())
\ No newline at end of file
